@@ -7,8 +7,8 @@ class Arduino:
 
 	def __init__(self):
 		self.buf = BufferedRead()
-		arduino = ReadArduinoUSB(self.buf)
-		arduino.start()
+		self.arduino = ReadArduinoUSB(self.buf)
+		self.arduino.start()
 
 	def get_last(self):
 		r = self.buf.get_last()
@@ -29,6 +29,7 @@ class BufferedRead:
 
 class ReadArduinoUSB(Thread):
 
+
 	def __init__(self, buf):
 		self.usb = serial.Serial("/dev/ttyUSB0", 9600)
 		self.buf = buf
@@ -39,6 +40,7 @@ class ReadArduinoUSB(Thread):
 			try:
 				self.buf.add(self.usb.readline())
 			except:
-				self.usb.close()
-				sys.exit(1)
+				pass
+		self.usb.close()
+		
 
