@@ -10,6 +10,7 @@ from IncreasingBPMWildness import IncreasingBPMWildness
 from IncreasingBPM import IncreasingBPM
 from DecreasingBPM import DecreasingBPM
 from DecreasingBPMWildness import DecreasingBPMWildness
+from ArduinoBlock import ArduinoBlock
 
 
 __all__ = ['Block', 'MutatingBlock', 
@@ -18,4 +19,4 @@ __all__ = ['Block', 'MutatingBlock',
 	'IncreasingWildness', 'DecreasingWildness', 
 	'IncreasingBPMWildness', 
 	'DecreasingBPM', 'IncreasingBPM', 
-	'DecreasingBPMWildness']
+	'DecreasingBPMWildness', 'ArduinoBlock']
