@@ -35,6 +35,10 @@ class Instrument:
 
 		if 'step' in parameters:
 			self.step = parameters["step"]
+			if 'start' not in parameters:
+				self.start = 0
+			if 'end' not in parameters:
+				self.end = self.start + self.step
 
 	def import_fluidsynth(self):
 		global fluidsynth
@@ -69,6 +73,7 @@ class Instrument:
 
 
 	def get_note_length(self, state):
+		"""The number of ticks that should be played."""
 		if 'let_ring' not in self.params:
 			return 1
 	
