@@ -4,9 +4,6 @@ from random import random
 
 class SimpleChordInstrument(Instrument):
 
-	def __init__(self, params):
-		Instrument.__init__(self, params)
-
 	def generate_note(self, state):
 		wild = state['wild']
 
