@@ -2,7 +2,7 @@ from Instrument import Instrument
 from mingus.core import chords
 from mingus.containers.Note import Note
 from mingus.containers.NoteContainer import NoteContainer
-from random import random
+from random import random, randrange
 
 
 class SlowStridePianist(Instrument):
@@ -12,6 +12,8 @@ class SlowStridePianist(Instrument):
 			params["let_ring"] = True
 		if 'channel' not in params:
 			params["channel"] = 1
+		if 'midi_instr' not in params:
+			params["midi_instr"] = randrange(1, 9)
 		Instrument.__init__(self, params)
 
 	def generate_note(self, state):
