@@ -18,9 +18,19 @@ class Sequencer:
 	update_function = None
 	verbose = False
 
-	def __init__(self, block):
-		self.block = block
-		self.play_iterations = block.get_duration()
+	def __init__(self, movement):
+		self.movement = movement
+		if not self.get_next_block():
+			sys.exit(0)
+
+	def get_next_block(self):
+		b = self.movement.get_next_block()
+		if b != None:
+			self.block = b
+			self.play_iterations = self.block.get_duration()
+			return True
+		return False
+
 
 	def block_iteration(self):
 		"""Queries the block class for information """
@@ -135,7 +145,10 @@ class Sequencer:
 				self.block_tick()
 				i += 1
 		self.block.stop()
-		self.output_midi()
+		if not self.get_next_block():
+			self.output_midi()
+		else:
+			self.play()
 
 	def output_midi(self):
 		c = Composition()
