@@ -1,7 +1,12 @@
 from Visualization import Visualization
-import pygame
-from pygame.locals import *
 from os import sys
+try:
+	import pygame
+	from pygame.locals import *
+except:
+	print "Couldn't load the pygame library."
+	print "A download is available at http://www.pygame.org"
+	sys.exit(1)
 
 class PygameVisualization(Visualization):
 	"""Visualizations using pygame should subclass this class and """
